# je_editor

##install

* please check your tkinter version
  * make sure tkinter is version 8.5 or later
  ```python
  # check tkinter version
  import tkinter
  tkinter._test()
  ```

* on Windows not need install any package
  * if fail to start tkinter
    * python version 3.7 and later will include new tk
    

* on macOS not need install any package
  * if fail to start tkinter 
    * xcode-select --install
      * download python-tk
        * brew install python-tk
    * or download new python version, new python version include new Tcl/Tk 
```
If you are using macOS 10.6 or later, 
the Apple-supplied Tcl/Tk 8.5 has serious bugs that can cause application crashes.
```
* on linux ubuntu use 
```commandline 
sudo sudo apt-get install python3-tk
```
* on fedora use
```commandline
sudo dnf python3-tk
```

 
